Review Board extension: CustomUrlAvatar
=======================================

This extension provides a simple way to add a
custom URL for user images.

This extension allows you to add system-wide
URL like an internal gravatar service.


Example:

https://images.mylocalcompany.org/?user={user}&s=${size}

This variables "{user}" and "{size}" will be filled by
Review Board for the corresponding user and needed size.

It is of course possible to omit these variables.

